@@ -187,6 +187,21 @@ QString KShutdownIface_stub::getStatusInfo()
     return result;
 }
 
+void KShutdownIface_stub::makeInvisible()
+{
+    if ( !dcopClient()  ) {
+	setStatus( CallFailed );
+	return;
+    }
+    QByteArray data, replyData;
+    QCString replyType;
+    if ( dcopClient()->call( app(), obj(), "makeInvisible()", data, replyType, replyData ) ) {
+	setStatus( CallSucceeded );
+    } else { 
+	callFailed();
+    }
+}
+
 void KShutdownIface_stub::makeVisible()
 {
     if ( !dcopClient()  ) {
