@@ -89,8 +89,9 @@ MActionEditDialog::MActionEditDialog(QWidget *parent, Action::Type action)
 	i_commandBeforeActionPause = new KIntNumInput(gb_commandBeforeAction, "KIntNumInput::i_commandBeforeActionPause");
 	i_commandBeforeActionPause->setLabel(i18n("Pause after run command:"));
 	i_commandBeforeActionPause->setRange(0, 300, 1, true);
+	i_commandBeforeActionPause->setSpecialValueText(i18n("No pause"));
 	i_commandBeforeActionPause->setSuffix(" " + i18n("second(s)"));
-	b_testCommandBeforeAction = new KPushButton(i18n("Test"), gb_commandBeforeAction, "KPushButton::b_testCommandBeforeAction");
+	b_testCommandBeforeAction = new KPushButton(KStdGuiItem::test(), gb_commandBeforeAction, "KPushButton::b_testCommandBeforeAction");
 	connect(b_testCommandBeforeAction, SIGNAL(clicked()), SLOT(slotTestCommandBeforeAction()));
 	connect(
 		c_runCommandBeforeAction, SIGNAL(toggled(bool)),
@@ -104,20 +105,20 @@ MActionEditDialog::MActionEditDialog(QWidget *parent, Action::Type action)
 
 	MTip *t_progs = new MTip(MTip::Warning, gb_south);
 	t_progs->setTipText(
-		"<qt>" +
-		i18n("In most cases you need privileges to shut down system (e.g. run /sbin/shutdown)") + "<br>" \
-		"<ul>" \
-		"<li>" + i18n("If you are using <b>KDE</b> and <b>KDM</b> (KDE Display Manager), then set all methods to <i>KDE</i>") + "</li>" \
-		"<li>" + i18n("If you are using <b>KDE</b> and display manager different than <b>KDM</b>, then set <i>Turn Off Computer</i> and <i>Restart Computer</i> methods to <i>/sbin/...</i>") + "</li>" \
-		"</ul>" +
-		i18n("Manuals:") +
-		"<ul>" \
-		"<li><a href=\"man:/halt\">halt, poweroff, reboot</a></li>" \
-		"<li><a href=\"man:/shutdown\">shutdown</a></li>" \
-		"<li><a href=\"man:/xlock\">xlock</a></li>" \
-		"<li><a href=\"man:/xscreensaver-command\">xscreensaver-command</a></li>" \
-		"</ul>" \
-		"</qt>"
+		MiscUtils::HTML(
+			i18n("In most cases you need privileges to shut down system (e.g. run /sbin/shutdown)") + "<br>" \
+			"<ul>" \
+				"<li>" + i18n("If you are using <b>KDE</b> and <b>KDM</b> (KDE Display Manager), then set all methods to <i>KDE</i>") + "</li>" \
+				"<li>" + i18n("If you are using <b>KDE</b> and display manager different than <b>KDM</b>, then set <i>Turn Off Computer</i> and <i>Restart Computer</i> methods to <i>/sbin/...</i>") + "</li>" \
+			"</ul>" +
+			i18n("Manuals:") +
+			"<ul>" \
+				"<li><a href=\"man:/halt\">halt, poweroff, reboot</a></li>" \
+				"<li><a href=\"man:/shutdown\">shutdown</a></li>" \
+				"<li><a href=\"man:/xlock\">xlock</a></li>" \
+				"<li><a href=\"man:/xscreensaver-command\">xscreensaver-command</a></li>" \
+			"</ul>" \
+		)
 	);
 
 	connect(this, SIGNAL(okClicked()), SLOT(slotOKClicked()));
@@ -150,7 +151,8 @@ MActionEditDialog::MActionEditDialog(QWidget *parent, Action::Type action)
 	b_testCommandBeforeAction->setEnabled(runCommand);
 	_methods->setFocus();
 
-	MiscUtils::pack(this);
+	adjustSize();
+	disableResize();
 }
 
 MActionEditDialog::~MActionEditDialog()
