@@ -19,10 +19,13 @@
 
 #include "actions.h"
 #include "configuration.h"
+#include "extras.h"
 #include "miscutils.h"
 #include "mmainwindow.h"
 #include "msystemtray.h"
 
+#include <qfileinfo.h>
+
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
@@ -31,7 +34,7 @@
 
 // 0.1.x, 0.3.x, etc - Unstable, Beta
 // 0.2.x, 0.4.x, etc - Stable
-QString version = "1.0.1";
+QString version = "1.0.2";
 
 KAboutData aboutData(
 	"kshutdown", // internal name
@@ -57,6 +60,8 @@ static KCmdLineOptions options[] =
 	{ "lock", I18N_NOOP("Lock session"), 0 },
 	{ "l", 0, 0 },
 	{ "logout", I18N_NOOP("End current session"), 0 },
+	{ "e", 0, 0 },
+	{ "extra <file>", I18N_NOOP("Execute \"Extras\" command (.desktop file)"), 0 },
 	{ "confirm", I18N_NOOP("Confirm command line action"), 0 },
 	{ "standard", I18N_NOOP("Show standard logout dialog"), 0 },
 	{ "c", 0, 0 },
@@ -301,6 +306,24 @@ int KShutDownApplication::doProcessArgs(const KCmdLineArgs *args) {
 		// exec action below ..
 	}
 
+	// extra
+	if (args->isSet("extra")) {
+		QString extrasCommand = args->getOption("extra");
+		if (!extrasCommand.isEmpty()) {
+			QFileInfo extra(extrasCommand);
+			if (extra.exists()) {
+				ks_extras->setAction(extra.filePath(), extra.baseName());
+				
+				return doExecAction(Action::Extras);
+			}
+			else {
+				qWarning("ERROR: File \"%s\" does not exist", extrasCommand.latin1());
+			}
+		}
+	
+		return Mode_Error;
+	}
+
 	// halt
 	if (args->isSet("shutdown") || args->isSet("halt"))
 		return doExecAction(Action::ShutDown);
