@@ -31,6 +31,7 @@
 #include "systemconfig.h"
 
 #include <qdatetimeedit.h>
+#include <qfile.h>
 #include <qhbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -84,7 +85,17 @@ MMainWindow::MMainWindow()
 	client->registerAs(kapp->name(), false);
 	client->setDefaultObject(objId()); // KShutdownIface
 
-	setAction((Action::Type)kshutdownrc->generalAction);
+	KConfig *config = kapp->config();
+	config->setGroup("Extras");
+	QString extrasCommand = config->readEntry("Command", QString::null);
+	QString extrasDescription = config->readEntry("Description", QString::null);
+	if (!extrasCommand.isEmpty() || QFile::exists(extrasCommand)) {
+		setAction(Action::Extras);
+		ks_extras->setAction(extrasCommand, extrasDescription);
+	}
+	else {
+		setAction((Action::Type)kshutdownrc->generalAction);
+	}
 	setDelayType((DelayType)kshutdownrc->generalDelayType);
 
 	MSystemTray::setMode((MSystemTray::Mode)kshutdownrc->systemTray);
@@ -97,6 +108,11 @@ MMainWindow::MMainWindow()
 
 MMainWindow::~MMainWindow()
 {
+	KConfig *config = kapp->config();
+	config->setGroup("Extras");
+	config->writeEntry("Command", ks_extras->fileToExecute());
+	config->writeEntry("Description", ks_extras->getActionDescription());
+
 // TODO: 2.0: remember/restore time
 	kshutdownrc->generalAction = ks_actions->current();
 	kshutdownrc->generalDelayType = cb_delayTypes->currentItem();
@@ -837,6 +853,8 @@ void MMainWindow::slotConfigureShortcuts()
 void MMainWindow::slotActionChange(int index)
 {
 	setAction((Action::Type)(index + 1)); // 0 = What_Nothing
+	if (ks_actions->current() != Action::Extras)
+		ks_extras->setAction(QString::null, QString::null);
 }
 
 void MMainWindow::slotCheckSystemConfig()
